Installation
============

The easiest way to install the package is using pip::

    $ pip install starmatrix

This will also install some dependencies if they are not found in the system: **numpy**, **scipy** and **pyyaml**


Updating
--------

A previous installation can be upgraded to the latest version with::

    $ pip install --upgrade starmatrix


Uninstall
---------

To remove Starmatrix from your system run::

    $ pip uninstall starmatrix
